@@ -6,7 +6,7 @@
 /*                                                                        */
 /* This is the language module with all the system messages               */
 /*                                                                        */
-/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
+/* If you made a translation, please go to the site and send to me        */
 /* the translated file. Please keep the original text order by modules,   */
 /* and just one message per line, also double check your translation!     */
 /*                                                                        */
@@ -698,5 +698,7 @@ define("_CENTERBLOCK","Center Block");
 define("_ADMINISTRATION","Administration");
 define("_NOADMINYET","There are no Administrators Accounts yet, proceeed to create the Super User:");
 define("_CREATEUSERDATA","Do you want to create a normal user with the same data?");
+define("_NORMAL","Normal");
+define("_INACTIVEBANNERS","Inactive Banners");
 
 ?>
\ No newline at end of file
