@@ -6,7 +6,7 @@
 /*                                                                        */
 /* This is the language module with all the system messages               */
 /*                                                                        */
-/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
+/* If you made a translation, please go to the site and send to me        */
 /* the translated file. Please keep the original text order by modules,   */
 /* and just one message per line, also double check your translation!     */
 /*                                                                        */
@@ -199,7 +199,7 @@ define("_EDITCATEGORY","Edit Category");
 define("_EDITQUESTIONS","Edit Questions and Answers");
 define("_FAQDELWARNING","WARNING: Are you sure you want to delete this Faq and all its content?");
 define("_QUESTIONDEL","WARNING: Are you sure you want to delete this Question?");
-define("_AUTHORSADMIN","Author's Adminitration");
+define("_AUTHORSADMIN","Author's Administration");
 define("_MODIFYINFO","Modify Info");
 define("_DELAUTHOR","Delete Author");
 define("_ADDAUTHOR","Add a New Administrator");
@@ -703,5 +703,7 @@ define("_CENTERBLOCK","Center Block");
 define("_ADMINISTRATION","Administration");
 define("_NOADMINYET","There are no Administrators Accounts yet, proceeed to create the Super User:");
 define("_CREATEUSERDATA","Do you want to create a normal user with the same data?");
+define("_NORMAL","Normal");
+define("_INACTIVEBANNERS","Inactive Banners");
 
 ?>
\ No newline at end of file
