@@ -6,7 +6,7 @@
 /*                                                                        */
 /* This is the language module with all the system messages               */
 /*                                                                        */
-/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
+/* If you made a translation, please go to the site and send to me        */
 /* the translated file. Please keep the original text order by modules,   */
 /* and just one message per line, also double check your translation!     */
 /*                                                                        */
@@ -694,5 +694,7 @@ define("_CREATEUSERDATA","Do you want to create a normal user with the same data
  define("_VERSION","");
  define("_HOMEPAGE","  ");
  define("_YOURLINKAT","   ");
+define("_NORMAL","Normal");
+define("_INACTIVEBANNERS","Inactive Banners");
 
 ?>
\ No newline at end of file
