@@ -4,7 +4,7 @@
 /* PHP-NUKE: Web Portal System                                          */
 /* ===========================                                          */
 /*                                                                      */
-/* Copyright (c) 2002 by Francisco Burzi (fbc@mandrakesoft.com)         */
+/* Copyright (c) 2002 by Francisco Burzi                                */
 /* http://phpnuke.org                                                   */
 /*                                                                      */
 /* This program is free software. You can redistribute it and/or modify */
@@ -43,15 +43,16 @@ function BannersAdmin() {
     OpenTable();
     echo "<center><font class=\"option\"><b>"._ACTIVEBANNERS."</b></font></center><br>"
 	."<table width=100% border=0><tr>"
-	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._ID."</b></td>"
+	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._CLIENTNAME."</b></td>"
 	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._IMPRESSIONS."</b></td>"
 	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._IMPLEFT."</b></td>"
 	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._CLICKS."</b></td>"
 	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._CLICKSPERCENT."</b></td>"
-	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._CLIENTNAME."</b></td>"
+	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._TYPE."</b></td>"
+	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._STATUS."</b></td>"
 	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._FUNCTIONS."</b></td><tr>";
-    $result = sql_query("select bid, cid, imptotal, impmade, clicks, date from ".$prefix."_banner order by bid", $dbi);
-    while(list($bid, $cid, $imptotal, $impmade, $clicks, $date) = sql_fetch_row($result, $dbi)) {
+    $result = sql_query("select bid, cid, imptotal, impmade, clicks, imageurl, date, type, active from ".$prefix."_banner order by bid", $dbi);
+    while(list($bid, $cid, $imptotal, $impmade, $clicks, $imageurl, $date, $type, $active) = sql_fetch_row($result, $dbi)) {
         $result2 = sql_query("select cid, name from ".$prefix."_bannerclient where cid=$cid", $dbi);
         list($cid, $name) = sql_fetch_row($result2, $dbi);
 	if($impmade==0) {
@@ -64,43 +65,26 @@ function BannersAdmin() {
 	} else {
 	    $left = $imptotal-$impmade;
 	}
-	echo "<td bgcolor=\"$bgcolor2\" align=center>$bid</td>"
+	if ($type == 0) {
+	    $type = _NORMAL;
+	} else {
+	    $type = _BLOCK;
+	}
+	if ($active == 1) {
+	    $t_active = _ACTIVE;
+	    $c_active = _DEACTIVATE;
+	} else {
+	    $t_active = "<i>"._INACTIVE."</i>";
+	    $c_active = _ACTIVATE;
+	}
+	echo "<td bgcolor=\"$bgcolor2\" align=center><a href=\"$imageurl\" target=\"new\">$name</a></td>"
 	    ."<td bgcolor=\"$bgcolor2\" align=center>$impmade</td>"
 	    ."<td bgcolor=\"$bgcolor2\" align=center>$left</td>"
 	    ."<td bgcolor=\"$bgcolor2\" align=center>$clicks</td>"
 	    ."<td bgcolor=\"$bgcolor2\" align=center>$percent%</td>"
-	    ."<td bgcolor=\"$bgcolor2\" align=center>$name</td>"
-	    ."<td bgcolor=\"$bgcolor2\" align=center><a href=\"admin.php?op=BannerEdit&amp;bid=$bid\">"._EDIT."</a> | <a href=\"admin.php?op=BannerDelete&amp;bid=$bid&amp;ok=0\">"._DELETE."</a></td><tr>";
-    }
-    echo "</td></tr></table>";
-    CloseTable();
-    echo "<br>";
-/* Finished Banners List */
-    echo "<a name=top>";
-    OpenTable();
-    echo "<center><font class=\"option\"><b>"._FINISHEDBANNERS."</b></font></center><br>"
-	."<table width=\"100%\" border=\"0\"><tr>"
-	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._ID."</b></td>"
-	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._IMP."</b></td>"
-	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._CLICKS."</b></td>"
-	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._CLICKSPERCENT."</b></td>"
-	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._DATESTARTED."</b></td>"
-	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._DATEENDED."</b></td>"
-	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._CLIENTNAME."</b></td>"
-	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._FUNCTIONS."</b></td><tr>";
-    $result = sql_query("select bid, cid, impressions, clicks, datestart, dateend from ".$prefix."_bannerfinish order by bid", $dbi);
-    while(list($bid, $cid, $impressions, $clicks, $datestart, $dateend) = sql_fetch_row($result, $dbi)) {
-        $result2 = sql_query("select cid, name from ".$prefix."_bannerclient where cid=$cid", $dbi);
-	list($cid, $name) = sql_fetch_row($result2, $dbi);
-	$percent = substr(100 * $clicks / $impressions, 0, 5);
-	echo "<td bgcolor=\"$bgcolor2\" align=\"center\">$bid</td>"
-	    ."<td bgcolor=\"$bgcolor2\" align=\"center\">$impressions</td>"
-	    ."<td bgcolor=\"$bgcolor2\" align=\"center\">$clicks</td>"
-	    ."<td bgcolor=\"$bgcolor2\" align=\"center\">$percent%</td>"
-	    ."<td bgcolor=\"$bgcolor2\" align=\"center\">$datestart</td>"
-	    ."<td bgcolor=\"$bgcolor2\" align=\"center\">$dateend</td>"
-	    ."<td bgcolor=\"$bgcolor2\" align=\"center\">$name</td>"
-	    ."<td bgcolor=\"$bgcolor2\" align=\"center\"><a href=\"admin.php?op=BannerFinishDelete&amp;bid=$bid\">"._DELETE."</a></td><tr>";
+	    ."<td bgcolor=\"$bgcolor2\" align=center>$type</td>"
+	    ."<td bgcolor=\"$bgcolor2\" align=center>$t_active</td>"
+	    ."<td bgcolor=\"$bgcolor2\" align=center>[ <a href=\"admin.php?op=BannerEdit&amp;bid=$bid\">"._EDIT."</a> | <a href=\"admin.php?op=BannerStatus&amp;bid=$bid&status=$active\">$c_active</a> | <a href=\"admin.php?op=BannerDelete&amp;bid=$bid&amp;ok=0\">"._DELETE."</a> ]</td><tr>";
     }
     echo "</td></tr></table>";
     CloseTable();
@@ -109,21 +93,23 @@ function BannersAdmin() {
     OpenTable();
     echo "<center><font class=\"option\"><b>"._ADVERTISINGCLIENTS."</b></font></center><br>"
 	."<table width=\"100%\" border=\"0\"><tr>"
-	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._ID."</b></td>"
 	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._CLIENTNAME."</b></td>"
 	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._ACTIVEBANNERS2."</b></td>"
+	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._INACTIVEBANNERS."</b></td>"
 	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._CONTACTNAME."</b></td>"
 	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._CONTACTEMAIL."</b></td>"
 	."<td bgcolor=\"$bgcolor2\" align=\"center\"><b>"._FUNCTIONS."</b></td><tr>";
     $result = sql_query("select cid, name, contact, email from ".$prefix."_bannerclient order by cid", $dbi);
     while(list($cid, $name, $contact, $email) = sql_fetch_row($result, $dbi)) {
-        $result2 = sql_query("select cid from ".$prefix."_banner where cid=$cid", $dbi);
+        $result2 = sql_query("select cid from ".$prefix."_banner WHERE cid=$cid AND active='1'", $dbi);
 	$numrows = sql_num_rows($result2, $dbi);
-	echo "<td bgcolor=\"$bgcolor2\" align=\"center\">$cid</td>"
-	    ."<td bgcolor=\"$bgcolor2\" align=\"center\">$name</td>"
+	$result2 = sql_query("select cid from ".$prefix."_banner WHERE cid=$cid AND active='0'", $dbi);
+	$numrows2 = sql_num_rows($result2, $dbi);
+	echo "<td bgcolor=\"$bgcolor2\" align=\"center\">$name</td>"
 	    ."<td bgcolor=\"$bgcolor2\" align=\"center\">$numrows</td>"
+	    ."<td bgcolor=\"$bgcolor2\" align=\"center\">$numrows2</td>"
 	    ."<td bgcolor=\"$bgcolor2\" align=\"center\">$contact</td>"
-	    ."<td bgcolor=\"$bgcolor2\" align=\"center\">$email</td>"
+	    ."<td bgcolor=\"$bgcolor2\" align=\"center\"><a href=\"mailto:$email\">$email</a></td>"
 	    ."<td bgcolor=\"$bgcolor2\" align=\"center\"><a href=\"admin.php?op=BannerClientEdit&amp;cid=$cid\">"._EDIT."</a> | <a href=\"admin.php?op=BannerClientDelete&amp;cid=$cid\">"._DELETE."</a></td><tr>";
     }
     echo "</td></tr></table>";
@@ -136,31 +122,37 @@ function BannersAdmin() {
 	OpenTable();
 	echo "<font class=\"option\"><b>"._ADDNEWBANNER."</b></font></center><br><br>"
 	    ."<form action=\"admin.php?op=BannersAdd\" method=\"post\">"
-	    .""._CLIENTNAME.":"
+	    .""._CLIENTNAME.": "
 	    ."<select name=\"cid\">";
 	$result = sql_query("select cid, name from ".$prefix."_bannerclient", $dbi);
 	while(list($cid, $name) = sql_fetch_row($result, $dbi)) {
 	    echo "<option value=\"$cid\">$name</option>";
 	}
-	echo "</select><br>"
-    	    .""._PURCHASEDIMPRESSIONS.": <input type=\"text\" name=\"imptotal\" size=\"12\" maxlength=\"11\"> 0 = "._UNLIMITED."<br>"
-	    .""._IMAGEURL.": <input type=\"text\" name=\"imageurl\" size=\"50\" maxlength=\"100\"><br>"
-	    .""._CLICKURL.": <input type=\"text\" name=\"clickurl\" size=\"50\" maxlength=\"200\"><br>"
+	echo "</select><br><br>"
+    	    .""._PURCHASEDIMPRESSIONS.": <input type=\"text\" name=\"imptotal\" size=\"12\" maxlength=\"11\"> 0 = "._UNLIMITED."<br><br>"
+	    .""._IMAGEURL.": <input type=\"text\" name=\"imageurl\" size=\"50\" maxlength=\"100\"><br><br>"
+	    .""._CLICKURL.": <input type=\"text\" name=\"clickurl\" size=\"50\" maxlength=\"200\"><br><br>"
+	    .""._TYPE.": <select name=\"type\">"
+	    ."<option name=\"type\" value=\"0\">"._NORMAL."</option>"
+	    ."<option name=\"type\" value=\"1\">"._BLOCK."</option>"
+	    ."</select><br><br>"
+	    .""._ACTIVATE.": <input type=\"radio\" name=\"active\" value=\"1\">"._YES."&nbsp;&nbsp;<input type=\"radio\" name=\"active\" value=\"0\">"._NO."<br><br>"
 	    ."<input type=\"hidden\" name=\"op\" value=\"BannersAdd\">"
 	    ."<input type=\"submit\" value=\""._ADDBANNER."\">"
 	    ."</form>";
 	CloseTable();
+	echo "<br>";
     }
 /* Add Client */
     OpenTable();
     echo"<font class=\"option\"><b>"._ADDCLIENT."</b></center><br><br>
 	<form action=\"admin.php?op=BannersAddClient\" method=\"post\">
-	"._CLIENTNAME.": <input type=\"text\" name=\"name\" size=\"30\" maxlength=\"60\"><br>
-	"._CONTACTNAME.": <input type=\"text\" name=\"contact\" size=\"30\" maxlength=\"60\"><br>
-	"._CONTACTEMAIL.": <input type=\"text\" name=\"email\" size=\"30\" maxlength=\"60\"><br>
-	"._CLIENTLOGIN.": <input type=\"text\" name=\"login\" size=\"12\" maxlength=\"10\"><br>
+	"._CLIENTNAME.": <input type=\"text\" name=\"name\" size=\"30\" maxlength=\"60\"><br><br>
+	"._CONTACTNAME.": <input type=\"text\" name=\"contact\" size=\"30\" maxlength=\"60\"><br><br>
+	"._CONTACTEMAIL.": <input type=\"text\" name=\"email\" size=\"30\" maxlength=\"60\"><br><br>
+	"._CLIENTLOGIN.": <input type=\"text\" name=\"login\" size=\"12\" maxlength=\"10\"><br><br>
 	"._CLIENTPASSWD.": <input type=\"text\" name=\"passwd\" size=\"12\" maxlength=\"10\"><br><br>
-	"._EXTRAINFO.":<br><textarea name=\"extrainfo\" cols=\"60\" rows=\"10\"></textarea><br>
+	"._EXTRAINFO.":<br><textarea name=\"extrainfo\" cols=\"60\" rows=\"10\"></textarea><br><br>
 	<input type=\"hidden\" name=\"op\" value=\"BannerAddClient\">
 	<input type=\"submit\" value=\""._ADDCLIENT2."\">
 	</form>";
@@ -168,9 +160,20 @@ function BannersAdmin() {
     include ("footer.php");
 }
 
-function BannersAdd($name, $cid, $imptotal, $imageurl, $clickurl) {
+function BannerStatus($bid, $status) {
     global $prefix, $dbi;
-    sql_query("insert into ".$prefix."_banner values (NULL, '$cid', '$imptotal', '1', '0', '$imageurl', '$clickurl', now())", $dbi);
+    if ($status == 1) {
+	$active = 0;
+    } else {
+	$active = 1;
+    }
+    $result = sql_query("update ".$prefix."_banner set active='$active' WHERE bid='$bid'", $dbi);
+    Header("Location: admin.php?op=BannersAdmin");
+}
+
+function BannersAdd($name, $cid, $imptotal, $imageurl, $clickurl, $type, $active) {
+    global $prefix, $dbi;
+    sql_query("insert into ".$prefix."_banner values (NULL, '$cid', '$imptotal', '1', '0', '$imageurl', '$clickurl', now(), '$type', '$active')", $dbi);
     Header("Location: admin.php?op=BannersAdmin#top");
 }
 
@@ -180,12 +183,6 @@ function BannerAddClient($name, $contact, $email, $login, $passwd, $extrainfo) {
     Header("Location: admin.php?op=BannersAdmin#top");
 }
 
-function BannerFinishDelete($bid) {
-    global $prefix, $dbi;
-    sql_query("delete from ".$prefix."_bannerfinish where bid=$bid", $dbi);
-    Header("Location: admin.php?op=BannersAdmin#top");
-}
-
 function BannerDelete($bid, $ok=0) {
     global $prefix, $dbi;
     if ($ok==1) {
@@ -241,11 +238,10 @@ function BannerEdit($bid) {
     echo "<center><font class=\"title\"><b>"._BANNERSADMIN."</b></font></center>";
     CloseTable();
     echo "<br>";
-    $result=sql_query("select cid, imptotal, impmade, clicks, imageurl, clickurl from ".$prefix."_banner where bid=$bid", $dbi);
-    list($cid, $imptotal, $impmade, $clicks, $imageurl, $clickurl) = sql_fetch_row($result, $dbi);
+    $result = sql_query("select cid, imptotal, impmade, clicks, imageurl, clickurl, type, active from ".$prefix."_banner where bid=$bid", $dbi);
+    list($cid, $imptotal, $impmade, $clicks, $imageurl, $clickurl, $type, $active) = sql_fetch_row($result, $dbi);
     OpenTable();
-    echo"<font class=\"option\">"
-	."<center><b>"._EDITBANNER."</b><br><br>"
+    echo"<center><b>"._EDITBANNER."</b><br><br>"
 	."<img src=\"$imageurl\" border=\"1\" alt=\"\"></center><br><br>"
 	."<form action=\"admin.php?op=BannerChange\" method=\"post\">"
 	.""._CLIENTNAME.": "
@@ -259,15 +255,34 @@ function BannerEdit($bid) {
 	    echo "<option value=\"$ccid\">$name</option>";
 	}
     }
-    echo "</select><br>";
+    echo "</select><br><br>";
     if($imptotal==0) {
         $impressions = _UNLIMITED;
     } else {
         $impressions = $imptotal;
     }
-    echo ""._ADDIMPRESSIONS.": <input type=\"text\" name=\"impadded\" size=\"12\" maxlength=\"11\"> "._PURCHASED."<b>$impressions</b> "._MADE.": <b>$impmade</b><br>"
-	.""._IMAGEURL.": <input type=\"text\" name=\"imageurl\" size=\"50\" maxlength=\"60\" value=\"$imageurl\"><br>"
-	.""._CLICKURL.": <input type=\"text\" name=\"clickurl\" size=\"50\" maxlength=\"100\" value=\"$clickurl\"><br>"
+    if ($type == 0) {
+	$sel1 = "selected";
+	$sel2 = "";
+    } else {
+	$sel1 = "";
+	$sel2 = "selected";
+    }
+    if ($active == 1) {
+	$check1 = "checked";
+	$check2 = "";
+    } else {
+	$check1 = "";
+	$check2 = "checked";
+    }
+    echo ""._ADDIMPRESSIONS.": <input type=\"text\" name=\"impadded\" size=\"12\" maxlength=\"11\"> "._PURCHASED.": <b>$impressions</b> "._MADE.": <b>$impmade</b><br><br>"
+	.""._IMAGEURL.": <input type=\"text\" name=\"imageurl\" size=\"50\" maxlength=\"60\" value=\"$imageurl\"><br><br>"
+	.""._CLICKURL.": <input type=\"text\" name=\"clickurl\" size=\"50\" maxlength=\"100\" value=\"$clickurl\"><br><br>"
+	.""._TYPE.": <select name=\"type\">"
+	."<option name=\"type\" value=\"0\" $sel1>"._NORMAL."</option>"
+	."<option name=\"type\" value=\"1\" $sel2>"._BLOCK."</option>"
+	."</select><br><br>"
+	.""._ACTIVATE.": <input type=\"radio\" name=\"active\" value=\"1\" $check1>"._YES."&nbsp;&nbsp;<input type=\"radio\" name=\"active\" value=\"0\" $check2>"._NO."<br><br>"
 	."<input type=\"hidden\" name=\"bid\" value=\"$bid\">"
 	."<input type=\"hidden\" name=\"imptotal\" value=\"$imptotal\">"
 	."<input type=\"hidden\" name=\"op\" value=\"BannerChange\">"
@@ -277,10 +292,10 @@ function BannerEdit($bid) {
     include("footer.php");
 }
 
-function BannerChange($bid, $cid, $imptotal, $impadded, $imageurl, $clickurl) {
+function BannerChange($bid, $cid, $imptotal, $impadded, $imageurl, $clickurl, $type, $active) {
     global $prefix, $dbi;
     $imp = $imptotal+$impadded;
-    sql_query("update ".$prefix."_banner set cid='$cid', imptotal='$imp', imageurl='$imageurl', clickurl='$clickurl' where bid=$bid", $dbi);
+    sql_query("update ".$prefix."_banner set cid='$cid', imptotal='$imp', imageurl='$imageurl', clickurl='$clickurl', type='$type', active='$active' where bid=$bid", $dbi);
     Header("Location: admin.php?op=BannersAdmin#top");
 }
 
@@ -334,12 +349,12 @@ function BannerClientEdit($cid) {
     OpenTable();
     echo "<center><font class=\"option\"><b>"._EDITCLIENT."</b></font></center><br><br>"
 	."<form action=\"admin.php?op=BannerClientChange\" method=\"post\">"
-	.""._CLIENTNAME.": <input type=\"text\" name=\"name\" value=\"$name\" size=\"30\" maxlength=\"60\"><br>"
-	.""._CONTACTNAME.": <input type=\"text\" name=\"contact\" value=\"$contact\" size=\"30\" maxlength=\"60\"><br>"
-	.""._CONTACTEMAIL.": <input type=\"text\" name=\"email\" size=30 maxlength=\"60\" value=\"$email\"><br>"
-	.""._CLIENTLOGIN.": <input type=\"text\" name=\"login\" size=12 maxlength=\"10\" value=\"$login\"><br>"
+	.""._CLIENTNAME.": <input type=\"text\" name=\"name\" value=\"$name\" size=\"30\" maxlength=\"60\"><br><br>"
+	.""._CONTACTNAME.": <input type=\"text\" name=\"contact\" value=\"$contact\" size=\"30\" maxlength=\"60\"><br><br>"
+	.""._CONTACTEMAIL.": <input type=\"text\" name=\"email\" size=30 maxlength=\"60\" value=\"$email\"><br><br>"
+	.""._CLIENTLOGIN.": <input type=\"text\" name=\"login\" size=12 maxlength=\"10\" value=\"$login\"><br><br>"
 	.""._CLIENTPASSWD.": <input type=\"text\" name=\"passwd\" size=12 maxlength=\"10\" value=\"$passwd\"><br><br>"
-	.""._EXTRAINFO."<br><textarea name=\"extrainfo\" cols=\"60\" rows=\"10\">$extrainfo</textarea><br>"
+	.""._EXTRAINFO."<br><textarea name=\"extrainfo\" cols=\"60\" rows=\"10\">$extrainfo</textarea><br><br>"
 	."<input type=\"hidden\" name=\"cid\" value=\"$cid\">"
 	."<input type=\"hidden\" name=\"op\" value=\"BannerClientChange\">"
 	."<input type=\"submit\" value=\""._SAVECHANGES."\">"
@@ -361,17 +376,13 @@ switch($op) {
     break;
 
     case "BannersAdd":
-    BannersAdd($name, $cid, $imptotal, $imageurl, $clickurl);
+    BannersAdd($name, $cid, $imptotal, $imageurl, $clickurl, $type, $active);
     break;
 
     case "BannerAddClient":
     BannerAddClient($name, $contact, $email, $login, $passwd, $extrainfo);
     break;
 
-    case "BannerFinishDelete":
-    BannerFinishDelete($bid);
-    break;
-
     case "BannerDelete":
     BannerDelete($bid, $ok);
     break;
@@ -381,7 +392,7 @@ switch($op) {
     break;
 		
     case "BannerChange":
-    BannerChange($bid, $cid, $imptotal, $impadded, $imageurl, $clickurl);
+    BannerChange($bid, $cid, $imptotal, $impadded, $imageurl, $clickurl, $type, $active);
     break;
 
     case "BannerClientDelete":
@@ -396,6 +407,10 @@ switch($op) {
     BannerClientChange($cid, $name, $contact, $email, $extrainfo, $login, $passwd);
     break;
 
+    case "BannerStatus":
+    BannerStatus($bid, $status);
+    break;
+
 }
 
 } else {
