@@ -4,7 +4,7 @@
 /* PHP-NUKE: Web Portal System                                          */
 /* ===========================                                          */
 /*                                                                      */
-/* Copyright (c) 2002 by Francisco Burzi (fbc@mandrakesoft.com)         */
+/* Copyright (c) 2002 by Francisco Burzi                                */
 /* http://phpnuke.org                                                   */
 /*                                                                      */
 /* This program is free software. You can redistribute it and/or modify */
@@ -184,8 +184,6 @@ function Configure() {
 	.""._FOOTERLINE2.":</td><td><textarea name=\"xfoot2\" cols=\"50\" rows=\"5\">".stripslashes($foot2)."</textarea>"
 	."</td></tr><tr><td>"
 	.""._FOOTERLINE3.":</td><td><textarea name=\"xfoot3\" cols=\"50\" rows=\"5\">".stripslashes($foot3)."</textarea>"
-	."</td></tr><tr><td>"
-	.""._FOOTERLINE4.":</td><td><textarea name=\"xfoot4\" cols=\"50\" rows=\"5\">".stripslashes($foot4)."</textarea>"
 	."</td></tr></table>";
     CloseTable();
     echo "<br>";
@@ -432,7 +430,6 @@ function ConfigSave($xsitename, $xnukeurl, $xsite_logo, $xslogan, $xstartdate, $
     $content .= "\$foot1 = \"$xfoot1\";\n";
     $content .= "\$foot2 = \"$xfoot2\";\n";
     $content .= "\$foot3 = \"$xfoot3\";\n";
-    $content .= "\$foot4 = \"$xfoot4\";\n";
     $content .= "\$commentlimit = $xcommentlimit;\n";
     $content .= "\$anonymous = \"$xanonymous\";\n";
     $content .= "\$minpass = $xminpass;\n";
@@ -600,6 +597,10 @@ function ConfigSave($xsitename, $xnukeurl, $xsite_logo, $xslogan, $xstartdate, $
     $content .= "# Do not touch the following options!\n";
     $content .= "$line";
     $content .= "\n";
+    $content .= "# DO NOT REMOVE THE FOLLOWING COPYRIGHT LINE\n";
+    $content .= "\$foot4 = \"Web site Engine's code is Copyright &copy; 2002 by <a href=\\\"http://phpnuke.org\\\">PHP-Nuke</a>. All Rights Reserved. PHP-Nuke is Free Software released under the <a href=\\\"http://www.gnu.org\\\">GNU/GPL license</a>.\";\n";
+    $content .= "# COPYRIGHT LINE ENDS HERE\n";
+    $content .= "\n";
     $content .= "\$tipath = \"$tipath\";\n";
     $content .= "\$Version_Num = \"$Version_Num\";\n\n";
     $content .= "if (eregi(\"config.php\",\$PHP_SELF)) {\n";
