@@ -4,7 +4,7 @@
 /* PHP-NUKE: Web Portal System                                          */
 /* ===========================                                          */
 /*                                                                      */
-/* Copyright (c) 2002 by Francisco Burzi (fbc@mandrakesoft.com)         */
+/* Copyright (c) 2002 by Francisco Burzi                                */
 /* http://phpnuke.org                                                   */
 /*                                                                      */
 /* This program is free software. You can redistribute it and/or modify */
@@ -12,12 +12,14 @@
 /* the Free Software Foundation; either version 2 of the License.       */
 /************************************************************************/
 
-/* This file is to customize whatever stuff you need to include in your site 
+/* 
+   This file is to customize whatever stuff you need to include in your site 
    when the header loads. This can be used for third party banners, custom
    javascript, popup windows, etc. With this file you don't need to edit 
    system code each time you upgrade to a new version. Just remember, in case
    you add code here to not overwrite this file when updating!
-   Whatever you put here will be between <head> and </head> tags. */
+   Whatever you put here will be between <head> and </head> tags.
+*/
 
 
 
