@@ -6,7 +6,7 @@ ob_start("ob_gzhandler");
 /* PHP-NUKE: Advanced Content Management System                         */
 /* ============================================                         */
 /*                                                                      */
-/* Copyright (c) 2002 by Francisco Burzi (fbc@mandrakesoft.com)         */
+/* Copyright (c) 2002 by Francisco Burzi                                */
 /* http://phpnuke.org                                                   */
 /*                                                                      */
 /* This program is free software. You can redistribute it and/or modify */
@@ -757,7 +757,7 @@ function automated_news() {
 
 function themecenterbox($title, $content) {
     OpenTable();
-    echo "<center><fon class=\"option\"><b>$title</b></font></center><br>"
+    echo "<center><font class=\"option\"><b>$title</b></font></center><br>"
 	."$content";
     CloseTable();
     echo "<br>";
