@@ -4,7 +4,7 @@
 /* PHP-NUKE: Web Portal System                                          */
 /* ===========================                                          */
 /*                                                                      */
-/* Copyright (c) 2002 by Francisco Burzi (fbc@mandrakesoft.com)         */
+/* Copyright (c) 2002 by Francisco Burzi                                */
 /* http://phpnuke.org                                                   */
 /*                                                                      */
 /* This program is free software. You can redistribute it and/or modify */
@@ -21,6 +21,13 @@ get_lang($module_name);
 $userpage = 1;
 
 function nav() {
+    $handle=opendir('themes');
+    while ($file = readdir($handle)) {
+	if ( (!ereg("[.]",$file)) ) {
+		$thmcount++;
+	}
+    }
+    closedir($handle);
     echo "<table border=\"0\" cellpadding=\"15\" align=\"center\"><tr><td>";
 
     echo "<font class=\"content\">"
@@ -38,11 +45,13 @@ function nav() {
 	."<a href=\"modules.php?name=Your_Account&amp;op=editcomm\">"._CONFIGCOMMENTS."</a>"
 	."</center></form></font></td>";
 
-    echo "<td><font class=\"content\">"
-	."<center><a href=\"modules.php?name=Your_Account&amp;op=chgtheme\"><img src=\"images/menu/themes.gif\" border=\"0\" alt=\""._SELECTTHETHEME."\"></a><br>"
-	."<a href=\"modules.php?name=Your_Account&amp;op=chgtheme\">"._SELECTTHETHEME."</a>"
-	."</center></form></font></td>";
-
+    if ($thmcount > 1) {
+	echo "<td><font class=\"content\">"
+	    ."<center><a href=\"modules.php?name=Your_Account&amp;op=chgtheme\"><img src=\"images/menu/themes.gif\" border=\"0\" alt=\""._SELECTTHETHEME."\"></a><br>"
+	    ."<a href=\"modules.php?name=Your_Account&amp;op=chgtheme\">"._SELECTTHETHEME."</a>"
+	    ."</center></form></font></td>";
+    }
+    
     echo "<td><font class=\"content\">"
 	."<center><a href=\"modules.php?name=Your_Account&amp;op=logout\"><img src=\"images/menu/exit.gif\" border=\"0\" alt=\""._LOGOUTEXIT."\"></a><br>"
 	."<a href=\"modules.php?name=Your_Account&amp;op=logout\">"._LOGOUTEXIT."</a>"
@@ -133,14 +142,14 @@ function confirmNewUser($uname, $email, $url, $user_avatar, $user_icq, $user_occ
 }
 
 function finishNewUser($uname, $email, $url, $user_avatar, $user_icq, $user_occ, $user_from, $user_intrest, $user_sig, $user_viewemail, $user_aim, $user_yim, $user_msnm) {
-    global $stop, $makepass, $EditedMessage, $adminmail, $sitename, $Default_Theme, $user_prefix, $dbi;
+    global $stop, $makepass, $EditedMessage, $adminmail, $sitename, $Default_Theme, $user_prefix, $dbi, $storyhome;
     include("header.php");
     userCheck($uname, $email);
     $user_regdate = date("M d, Y");
     if (!isset($stop)) {
 	$makepass=makepass();
 	$cryptpass = md5($makepass);
-	$result = sql_query("insert into ".$user_prefix."_users values (NULL,'','$uname','$email','','$url','$user_avatar','$user_regdate','$user_icq','$user_occ','$user_from','$user_intrest','$user_sig','$user_viewemail','','$user_aim','$user_yim','$user_msnm','$cryptpass','10','','0','0','0','','0','','$Default_Theme','$commentlimit','0','0','0','0','0','1')", $dbi);
+	$result = sql_query("insert into ".$user_prefix."_users values (NULL,'','$uname','$email','','$url','$user_avatar','$user_regdate','$user_icq','$user_occ','$user_from','$user_intrest','$user_sig','$user_viewemail','','$user_aim','$user_yim','$user_msnm','$cryptpass','$storyhome','','0','0','0','','0','','$Default_Theme','$commentlimit','0','0','0','0','0','1')", $dbi);
 	if(!$result) {
 	    echo ""._ERROR."<br>";
 	} else {
